@@ -77,7 +77,7 @@ class M3U8Init:
     def video_name(self, name):
         video = os.path.join(self.video_path, name or self.default_video_name)
         video = "-".join(video.split())
-        video = utils.rename(video, suffix="mp4")[0]
+        video = utils.rename_file(video, suffix="mp4")[0]
         self._video_path, self._video_name = os.path.split(video)
 
     @property
